//css_ref System.Data;
//css_ref System.Transactions;
//css_ref System.Xml;
//css_ref Interop.SAPbobsCOM.dll;
//css_ref log4net.dll;
//css_ref Produmex.Foundation.dll;
//css_ref Produmex.Foundation.Data.Sbo.dll;
//css_ref Produmex.Sbo.Logex.Data.dll;
//css_ref Produmex.Sbo.Logex.RevisionSkincare.dll;

using System;
using System.Diagnostics;
using System.Reflection;
using System.Transactions;
using Produmex.Foundation.Data.Sbo;
using Produmex.Foundation.Data.Sbo.Providers;
using Produmex.Foundation.Diagnostics;
using Produmex.Sbo.Logex.Data.BusinessObjects;
using Produmex.Sbo.Logex.Data.Providers;
using Produmex.Sbo.Logex.RevisionSkincare.BusinessObjects;
using Produmex.Sbo.Logex.RevisionSkincare.BusinessObjects.Definitions.Tables;
using PmxItem = Produmex.Sbo.Logex.RevisionSkincare.BusinessObjects.PmxItem;

namespace AddUpdateScript
{
	class Program
	{
		static string CONNECTION_STRING = "Server=DEV_SAP9_FR;CompanyDB=SBODemo_US_64;ExtraDb=PMX_SBODemo_US_64;UseTrusted=False;DbUserName=sa;DbPassword=B1Admin;UserName=manager;Password=produmex;Pooling=True;MinPoolSize=2;MaxPoolSize=10;ServerType=MSSQL2008;DBCultureInfo=en-US;LicenseServer=localhost:30000";

		/// <summary>
		/// Used for logging
		/// </summary>
		private static readonly ILog s_log = LogProvider.GetLogger(MethodInfo.GetCurrentMethod().DeclaringType);

		private static void Main(string[] args)
		{
			try
			{
				LogProvider.SetConsoleAppender("WARN");
				Execute();
			}
			catch (Exception ex)
			{
				s_log.Error("", ex);
			}
			if (Debugger.IsAttached)
			{
				Console.WriteLine("Press <Enter>");
				Console.ReadLine();
			}
		}

		private static void Execute()
		{

			CreatingUDF();

			CreatingTables();

			Console.WriteLine("Done ...");
		}

		private static void CreatingTables()
		{
			using (PmxDbConnectionSql conn = new PmxDbConnectionSql(CONNECTION_STRING))
			{
				conn.Open(); //Open connection to SAP
				Console.WriteLine("Connection is open to database");

				Console.WriteLine("Creating tables");

				conn.DbTool.CreateUpdateTableNotInTransaction(typeof(PmxRevisionNumbersTable));
			}
		}

		private static void CreatingUDF()
		{
			using (TransactionScope scope = PmxDbConnection.GetNewTransactionScope())
			{
				using (SboConnection conn = new SboConnection(CONNECTION_STRING))
				{
					conn.Open(); //Open connection to SAP
					Console.WriteLine("Connection is open to database");

					Console.WriteLine("Creating UDFs");

					AddUpdateUserFieldsNotInTransaction(conn, typeof(PmxItem));
				}

				//Complete transaction
				scope.Complete();
			}
		}

		/// <summary>
		/// Adds the update user fields not in transaction.
		/// </summary>
		/// <param name="conn">The conn.</param>
		/// <param name="types">The types.</param>
		private static void AddUpdateUserFieldsNotInTransaction(SboConnection conn, params Type[] types)
		{
			SboUserFieldMDProvider userFieldMDProv = new SboUserFieldMDProvider(conn);
			userFieldMDProv.AddUpdateUserFields(types);
		}
	}
}
